UpdateResult

Struct UpdateResult 

pub struct UpdateResult<S, M> {
    pub state: Option<S>,
    pub command: Command<M>,
}
Result of an update operation.

This provides a convenient way to return both state changes and commands from an update function.

Fields

state: Option<S>

The updated state (if changed)

command: Command<M>

Commands to execute

Implementations

Source

impl<S, M> UpdateResult<S, M>

pub fn none() -> Self

Creates a result with no state change and no command.

pub fn state(state: S) -> Self

Creates a result with updated state.

pub fn command(command: Command<M>) -> Self

Creates a result with a command.

pub fn with(state: S, command: Command<M>) -> Self

Creates a result with both state and command.

pub fn and_command(self, command: Command<M>) -> Self

Adds a command to this result.

pub fn map_state<T, F>(self, f: F) -> UpdateResult<T, M>
where F: FnOnce(S) -> T,

Maps the state type.

pub fn map_message<N, F>(self, f: F) -> UpdateResult<S, N>
where F: Fn(M) -> N + Clone + Send + 'static, M: Send + 'static, N: Send + 'static,

Maps the message type.