pub enum DataGridMessage {
Show 13 variants
Up,
Down,
First,
Last,
Left,
Right,
Enter,
Cancel,
Input(char),
Backspace,
Delete,
Home,
End,
}Expand description
Messages that can be sent to a DataGrid.
Variants
Up
Move selection up by one row.
Down
Move selection down by one row.
First
Move selection to the first row.
Last
Move selection to the last row.
Left
Move the column cursor left.
Right
Move the column cursor right.
Enter
Start editing the current cell, or confirm the edit.
Cancel
Cancel the current edit.
Input(char)
Type a character while editing.
Backspace
Delete the character before the cursor while editing.
Delete
Delete the character after the cursor while editing.
Home
Move cursor to the start of the cell while editing.
End
Move cursor to the end of the cell while editing.