Chart

Struct Chart 

pub struct Chart(/* private fields */);
A chart component for data visualization.

Supports line charts (braille rendering with shared axes), vertical bar charts, horizontal bar charts, area charts (filled line), and scatter plots with multiple data series, threshold lines, logarithmic scaling, smart tick labels, LTTB downsampling, and manual Y-axis scaling.

Key Bindings

  • Tab — Cycle to next series
  • BackTab — Cycle to previous series
  • Left / h — Move crosshair cursor left
  • Right / l — Move crosshair cursor right
  • Home — Move crosshair cursor to start
  • End — Move crosshair cursor to end
  • c — Toggle crosshair cursor visibility
  • g — Toggle grid line visibility