Divider

Struct Divider 

pub struct Divider;
A horizontal or vertical separator line with optional label.

Divider renders a line of box-drawing characters ( for horizontal, for vertical) to visually separate content areas. An optional label can be centered on the divider line.

This is a display-only component that does not receive keyboard focus.

Example

use envision::component::{Component, Divider, DividerState, DividerMessage};

let mut state = DividerState::new().with_label("Settings");
assert_eq!(state.label(), Some("Settings"));

Divider::update(&mut state, DividerMessage::SetLabel(None));
assert_eq!(state.label(), None);