pub struct Menu;Expand description
A horizontal menu bar component.
This component provides a horizontal menu bar for application commands and navigation. Items can be navigated with Left/Right arrows and activated with Enter.
Keyboard Navigation
The menu itself doesn’t handle keyboard events directly. Your application should map:
- Right arrow to
MenuMessage::Right - Left arrow to
MenuMessage::Left - Enter to
MenuMessage::Select
Visual Layout
File Edit View Help
^^^^
└── Selected item (highlighted)Example
use envision::component::{Menu, MenuMessage, MenuOutput, MenuState, MenuItem, Component};
let mut state = MenuState::new(vec![
MenuItem::new("New"),
MenuItem::new("Open"),
MenuItem::disabled("Save"),
]);
// Navigate
Menu::update(&mut state, MenuMessage::Right);
// Select
let output = Menu::update(&mut state, MenuMessage::Select);
assert_eq!(output, Some(MenuOutput::Selected(1)));Trait Implementations
Sourceimpl Component for Menu
impl Component for Menu
Sourcetype Message = MenuMessage
type Message = MenuMessage
Messages this component can receive. Read more
Sourcetype Output = MenuOutput
type Output = MenuOutput
Messages this component can emit to its parent. Read more
Sourcefn update(state: &mut Self::State, msg: Self::Message) -> Option<Self::Output>
fn update(state: &mut Self::State, msg: Self::Message) -> Option<Self::Output>
Update component state based on a message. Read more
Sourcefn handle_event(
_state: &Self::State,
event: &Event,
ctx: &ViewContext,
) -> Option<Self::Message>
fn handle_event( _state: &Self::State, event: &Event, ctx: &ViewContext, ) -> Option<Self::Message>
Maps an input event to a component message. Read more
Sourcefn view(
state: &Self::State,
frame: &mut Frame<'_>,
area: Rect,
theme: &Theme,
ctx: &ViewContext,
)
fn view( state: &Self::State, frame: &mut Frame<'_>, area: Rect, theme: &Theme, ctx: &ViewContext, )
Render the component to the given area. Read more
Sourcefn traced_view(
state: &Self::State,
frame: &mut Frame<'_>,
area: Rect,
theme: &Theme,
ctx: &ViewContext,
)
fn traced_view( state: &Self::State, frame: &mut Frame<'_>, area: Rect, theme: &Theme, ctx: &ViewContext, )
Renders the component with optional tracing instrumentation. Read more
Sourcefn dispatch_event(
state: &mut Self::State,
event: &Event,
ctx: &ViewContext,
) -> Option<Self::Output>
fn dispatch_event( state: &mut Self::State, event: &Event, ctx: &ViewContext, ) -> Option<Self::Output>
Dispatches an event by mapping it to a message and updating state. Read more