pub struct MenuState { /* private fields */ }Expand description
State for a Menu component.
Implementations
Sourceimpl MenuState
impl MenuState
Sourcepub fn new(items: Vec<MenuItem>) -> Self
pub fn new(items: Vec<MenuItem>) -> Self
Creates a new menu with the given items.
Example
use envision::component::{MenuState, MenuItem};
let state = MenuState::new(vec![
MenuItem::new("File"),
MenuItem::new("Edit"),
]);
assert_eq!(state.items().len(), 2);Sourcepub fn items(&self) -> &[MenuItem]
pub fn items(&self) -> &[MenuItem]
Returns the menu items.
Examples
use envision::prelude::*;
let state = MenuState::new(vec![
MenuItem::new("File"),
MenuItem::new("Edit"),
]);
assert_eq!(state.items().len(), 2);
assert_eq!(state.items()[0].label(), "File");Sourcepub fn set_items(&mut self, items: Vec<MenuItem>)
pub fn set_items(&mut self, items: Vec<MenuItem>)
Sets the menu items.
Resets selection to the first item if the current selection is out of bounds.
Sets selection to None if the new items list is empty.
Example
use envision::component::{MenuState, MenuItem};
let mut state = MenuState::new(vec![MenuItem::new("File")]);
state.set_items(vec![MenuItem::new("A"), MenuItem::new("B"), MenuItem::new("C")]);
assert_eq!(state.items().len(), 3);Sourcepub fn add_item(&mut self, item: MenuItem)
pub fn add_item(&mut self, item: MenuItem)
Adds a menu item.
If this is the first item, it becomes selected.
Example
use envision::component::{MenuState, MenuItem};
let mut state = MenuState::new(vec![MenuItem::new("File")]);
state.add_item(MenuItem::new("Edit"));
assert_eq!(state.items().len(), 2);Sourcepub fn remove_item(&mut self, index: usize)
pub fn remove_item(&mut self, index: usize)
Removes a menu item by index.
If the index is out of bounds, this is a no-op. Adjusts the selection after removal:
- If the removed item was the selected item, selects the previous item (or the first if at the beginning).
- If the menu becomes empty, selection becomes
None.
Example
use envision::component::{MenuState, MenuItem};
let mut state = MenuState::new(vec![
MenuItem::new("File"),
MenuItem::new("Edit"),
MenuItem::new("View"),
]);
state.remove_item(1);
assert_eq!(state.items().len(), 2);Sourcepub fn selected_index(&self) -> Option<usize>
pub fn selected_index(&self) -> Option<usize>
Returns the currently selected item index.
Returns None if the menu is empty.
Examples
use envision::prelude::*;
let state = MenuState::new(vec![MenuItem::new("File"), MenuItem::new("Edit")]);
assert_eq!(state.selected_index(), Some(0));
let empty = MenuState::new(vec![]);
assert_eq!(empty.selected_index(), None);Sourcepub fn selected(&self) -> Option<usize>
pub fn selected(&self) -> Option<usize>
Alias for selected_index().
Example
use envision::component::{MenuState, MenuItem};
let state = MenuState::new(vec![MenuItem::new("File"), MenuItem::new("Edit")]);
assert_eq!(state.selected(), Some(0));Sourcepub fn set_selected(&mut self, index: Option<usize>)
pub fn set_selected(&mut self, index: Option<usize>)
Sets the selected item index.
Pass Some(index) to select an item (clamped to valid range), or
None to clear the selection. Has no effect on an empty menu when
selecting.
Example
use envision::component::{MenuState, MenuItem};
let mut state = MenuState::new(vec![
MenuItem::new("File"),
MenuItem::new("Edit"),
MenuItem::new("View"),
]);
state.set_selected(Some(2));
assert_eq!(state.selected_index(), Some(2));Sourcepub fn with_selected(self, index: usize) -> Self
pub fn with_selected(self, index: usize) -> Self
Sets the selected item index (builder method).
If the index is out of bounds, it will be clamped to the valid range. Has no effect on an empty menu.
Example
use envision::component::{MenuState, MenuItem};
let state = MenuState::new(vec![
MenuItem::new("File"),
MenuItem::new("Edit"),
MenuItem::new("View"),
]).with_selected(1);
assert_eq!(state.selected_index(), Some(1));Sourcepub fn selected_item(&self) -> Option<&MenuItem>
pub fn selected_item(&self) -> Option<&MenuItem>
Returns the currently selected item.
Examples
use envision::prelude::*;
let state = MenuState::new(vec![MenuItem::new("File"), MenuItem::new("Edit")]);
assert_eq!(state.selected_item().unwrap().label(), "File");Sourcepub fn update(&mut self, msg: MenuMessage) -> Option<MenuOutput>
pub fn update(&mut self, msg: MenuMessage) -> Option<MenuOutput>
Updates the menu state with a message, returning any output.
Example
use envision::component::{MenuMessage, MenuOutput, MenuState, MenuItem};
let mut state = MenuState::new(vec![
MenuItem::new("File"),
MenuItem::new("Edit"),
]);
let output = state.update(MenuMessage::Right);
assert_eq!(output, Some(MenuOutput::SelectionChanged(1)));Trait Implementations
Sourceimpl<'de> Deserialize<'de> for MenuState
impl<'de> Deserialize<'de> for MenuState
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
impl StructuralPartialEq for MenuState