Switch

Struct Switch 

pub struct Switch;
An on/off toggle switch component.

This component provides a boolean on/off input that can be toggled via keyboard when focused. The switch emits SwitchOutput::Toggled, SwitchOutput::On, or SwitchOutput::Off messages when toggled.

Keyboard Activation

When focused, Enter or Space toggles the switch state.

Visual States

  • Off: ( ) OFF
  • On: (*) ON with success/green coloring
  • Focused: Yellow/focused text
  • Disabled: Dark gray text, doesn’t respond to toggle
  • With label: Label (*) ON

Example

use envision::component::{Switch, SwitchMessage, SwitchOutput, SwitchState, Component};

let mut state = SwitchState::new();

// Toggle the switch on
let output = Switch::update(&mut state, SwitchMessage::Toggle);
assert_eq!(output, Some(SwitchOutput::On));
assert!(state.is_on());