pub struct ThresholdZone {
pub above: f64,
pub color: Color,
}Expand description
A threshold zone with a color and breakpoint.
Threshold zones define color changes based on the gauge’s current
percentage. When the gauge percentage is at or above the above value,
and below any higher threshold, this zone’s color is used.
Example
use envision::component::ThresholdZone;
use ratatui::style::Color;
let zone = ThresholdZone {
above: 0.7,
color: Color::Yellow,
};
assert_eq!(zone.above, 0.7);
assert_eq!(zone.color, Color::Yellow);Fields
above: f64Values at or above this percentage trigger this zone’s color.
color: ColorThe color for this zone.