pub struct TitleCard;Expand description
A stylish display-only component for application titles.
Renders a centered title with optional decorations, subtitle, and borders. This is a display-only component that does not receive keyboard focus.
Example
use envision::component::{Component, TitleCard, TitleCardState};
let state = TitleCardState::new("My Application")
.with_subtitle("v1.0.0")
.with_prefix("🎯 ");
assert_eq!(state.title(), "My Application");
assert_eq!(state.subtitle(), Some("v1.0.0"));Trait Implementations
Sourceimpl Component for TitleCard
impl Component for TitleCard
Sourcetype State = TitleCardState
type State = TitleCardState
The component’s internal state type. Read more
Sourcetype Message = TitleCardMessage
type Message = TitleCardMessage
Messages this component can receive. Read more
Sourcefn update(state: &mut Self::State, msg: Self::Message) -> Option<Self::Output>
fn update(state: &mut Self::State, msg: Self::Message) -> Option<Self::Output>
Update component state based on a message. Read more
Sourcefn view(
state: &Self::State,
frame: &mut Frame<'_>,
area: Rect,
theme: &Theme,
ctx: &ViewContext,
)
fn view( state: &Self::State, frame: &mut Frame<'_>, area: Rect, theme: &Theme, ctx: &ViewContext, )
Render the component to the given area. Read more
Sourcefn traced_view(
state: &Self::State,
frame: &mut Frame<'_>,
area: Rect,
theme: &Theme,
ctx: &ViewContext,
)
fn traced_view( state: &Self::State, frame: &mut Frame<'_>, area: Rect, theme: &Theme, ctx: &ViewContext, )
Renders the component with optional tracing instrumentation. Read more
Sourcefn handle_event(
state: &Self::State,
event: &Event,
ctx: &ViewContext,
) -> Option<Self::Message>
fn handle_event( state: &Self::State, event: &Event, ctx: &ViewContext, ) -> Option<Self::Message>
Maps an input event to a component message. Read more
Sourcefn dispatch_event(
state: &mut Self::State,
event: &Event,
ctx: &ViewContext,
) -> Option<Self::Output>
fn dispatch_event( state: &mut Self::State, event: &Event, ctx: &ViewContext, ) -> Option<Self::Output>
Dispatches an event by mapping it to a message and updating state. Read more