pub struct UnboundedChannelSubscription<M> { /* private fields */ }Expand description
A subscription that receives messages from an unbounded channel.
This is the unbounded counterpart of ChannelSubscription. Use this
when the sender should never block, at the cost of unbounded memory
growth if messages are produced faster than consumed.
Example
use envision::app::UnboundedChannelSubscription;
let (tx, rx) = tokio::sync::mpsc::unbounded_channel::<String>();
let subscription = UnboundedChannelSubscription::new(rx);Implementations
Sourceimpl<M> UnboundedChannelSubscription<M>
impl<M> UnboundedChannelSubscription<M>
Sourcepub fn new(receiver: UnboundedReceiver<M>) -> Self
pub fn new(receiver: UnboundedReceiver<M>) -> Self
Creates a subscription from an unbounded channel receiver.