pub enum ChatViewMessage {
Show 23 variants
Input(char),
NewLine,
Backspace,
Delete,
Left,
Right,
Up,
Down,
Home,
End,
Submit,
ToggleFocus,
FocusInput,
FocusHistory,
ScrollUp,
ScrollDown,
ScrollToTop,
ScrollToBottom,
ClearInput,
InputStart,
InputEnd,
DeleteToEnd,
DeleteToStart,
}Expand description
Messages that can be sent to a ChatView.
Variants
Input(char)
Type a character in the input field.
NewLine
Insert a newline in the input field.
Backspace
Delete the character before the cursor.
Delete
Delete the character at the cursor.
Left
Move cursor left in the input field.
Right
Move cursor right in the input field.
Up
Move cursor up in the input field or scroll history.
Down
Move cursor down in the input field or scroll history.
Home
Move cursor to start of line.
End
Move cursor to end of line.
Submit
Submit the current input as a user message.
ToggleFocus
Toggle focus between history and input.
FocusInput
Focus the input field.
FocusHistory
Focus the message history.
ScrollUp
Scroll history up by one line.
ScrollDown
Scroll history down by one line.
ScrollToTop
Scroll to the top of history.
ScrollToBottom
Scroll to the bottom of history (newest).
ClearInput
Clear the input field.
InputStart
Move cursor to the start of the input.
InputEnd
Move cursor to the end of the input.
DeleteToEnd
Delete from cursor to end of line.
DeleteToStart
Delete from line start to cursor.