pub enum EventLevel {
Trace,
Debug,
Info,
Warning,
Error,
Fatal,
}Expand description
Severity level for a stream event.
Levels are ordered from least to most severe, allowing minimum-level filtering (e.g., show only Warning and above).
Example
use envision::component::EventLevel;
assert!(EventLevel::Error > EventLevel::Info);
assert!(EventLevel::Trace < EventLevel::Debug);
assert_eq!(EventLevel::default(), EventLevel::Info);Variants
Trace
Finest-grained informational events.
Debug
Fine-grained informational events useful for debugging.
Info
Informational messages highlighting normal operation.
Warning
Potentially harmful situations.
Error
Error events that might still allow the application to continue.
Fatal
Very severe error events that will likely cause the application to abort.
Implementations
Sourceimpl EventLevel
impl EventLevel
Sourcepub fn abbreviation(&self) -> &'static str
pub fn abbreviation(&self) -> &'static str
Returns a short abbreviation for display (3 chars).
Example
use envision::component::EventLevel;
assert_eq!(EventLevel::Info.abbreviation(), "INF");
assert_eq!(EventLevel::Error.abbreviation(), "ERR");Sourcepub fn color(&self) -> Color
pub fn color(&self) -> Color
Returns the display color for this severity level.
- Trace: DarkGray (dim)
- Debug: Gray
- Info: Blue
- Warning: Yellow
- Error: Red
- Fatal: LightRed (bright red)
Example
use envision::component::EventLevel;
use ratatui::style::Color;
assert_eq!(EventLevel::Info.color(), Color::Blue);
assert_eq!(EventLevel::Error.color(), Color::Red);Trait Implementations
Sourceimpl Clone for EventLevel
impl Clone for EventLevel
Sourcefn clone(&self) -> EventLevel
fn clone(&self) -> EventLevel
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EventLevel
impl Debug for EventLevel
Sourceimpl Default for EventLevel
impl Default for EventLevel
Sourcefn default() -> EventLevel
fn default() -> EventLevel
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for EventLevel
impl<'de> Deserialize<'de> for EventLevel
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for EventLevel
impl Display for EventLevel
Sourceimpl Hash for EventLevel
impl Hash for EventLevel
Sourceimpl Ord for EventLevel
impl Ord for EventLevel
Sourcefn cmp(&self, other: &EventLevel) -> Ordering
fn cmp(&self, other: &EventLevel) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for EventLevel
impl PartialEq for EventLevel
Sourceimpl PartialOrd for EventLevel
impl PartialOrd for EventLevel
Sourceimpl Serialize for EventLevel
impl Serialize for EventLevel
impl Eq for EventLevel
impl StructuralPartialEq for EventLevel