pub struct Chart(/* private fields */);Expand description
A chart component for data visualization.
Supports line charts (braille rendering with shared axes), vertical bar charts, horizontal bar charts, area charts (filled line), and scatter plots with multiple data series, threshold lines, logarithmic scaling, smart tick labels, LTTB downsampling, and manual Y-axis scaling.
Key Bindings
Tab— Cycle to next seriesBackTab— Cycle to previous seriesLeft/h— Move crosshair cursor leftRight/l— Move crosshair cursor rightHome— Move crosshair cursor to startEnd— Move crosshair cursor to endc— Toggle crosshair cursor visibilityg— Toggle grid line visibility