pub struct DialogButton { /* private fields */ }Expand description
A button configuration for a dialog.
Each button has a unique identifier that is returned when the button is pressed, and a display label shown to the user.
Example
use envision::component::DialogButton;
let button = DialogButton::new("save", "Save Changes");
assert_eq!(button.id(), "save");
assert_eq!(button.label(), "Save Changes");Implementations