pub struct Spinner;Expand description
An indeterminate loading indicator component.
Spinner displays an animated indicator to show ongoing activity.
Unlike ProgressBar, it does not show specific
progress - just that something is happening.
Animation
The spinner advances one frame each time it receives a Tick message.
Your application should send Tick messages at regular intervals
(typically every 80-100ms) to create smooth animation.
Styles
Several built-in styles are available:
Dots: Braille dots (⠋⠙⠹⠸⠼⠴⠦⠧⠇⠏) - defaultLine: Classic ASCII (|/-\)Circle: Quarter circles (◐◓◑◒)Bounce: Bouncing dot (⠁⠂⠄⠂)Custom: Your own character sequence
Example
use envision::component::{Spinner, SpinnerMessage, SpinnerState, Component};
let mut state = SpinnerState::with_label("Processing...");
// In your app's update function, forward timer ticks:
Spinner::update(&mut state, SpinnerMessage::Tick);
// Stop when done:
Spinner::update(&mut state, SpinnerMessage::Stop);Trait Implementations
Sourceimpl Component for Spinner
impl Component for Spinner
Sourcetype State = SpinnerState
type State = SpinnerState
The component’s internal state type. Read more
Sourcetype Message = SpinnerMessage
type Message = SpinnerMessage
Messages this component can receive. Read more
Sourcefn update(state: &mut Self::State, msg: Self::Message) -> Option<Self::Output>
fn update(state: &mut Self::State, msg: Self::Message) -> Option<Self::Output>
Update component state based on a message. Read more
Sourcefn view(
state: &Self::State,
frame: &mut Frame<'_>,
area: Rect,
theme: &Theme,
_ctx: &ViewContext,
)
fn view( state: &Self::State, frame: &mut Frame<'_>, area: Rect, theme: &Theme, _ctx: &ViewContext, )
Render the component to the given area. Read more
Sourcefn traced_view(
state: &Self::State,
frame: &mut Frame<'_>,
area: Rect,
theme: &Theme,
ctx: &ViewContext,
)
fn traced_view( state: &Self::State, frame: &mut Frame<'_>, area: Rect, theme: &Theme, ctx: &ViewContext, )
Renders the component with optional tracing instrumentation. Read more
Sourceimpl Disableable for Spinner
impl Disableable for Spinner
Sourcefn is_disabled(state: &Self::State) -> bool
fn is_disabled(state: &Self::State) -> bool
Returns true if this component is currently disabled.
Sourcefn set_disabled(state: &mut Self::State, disabled: bool)
fn set_disabled(state: &mut Self::State, disabled: bool)
Sets the disabled state of this component.